@@ -16,7 +16,7 @@ use Plack::Util::Accessor qw/ client sample_rate /;
 use Time::HiRes;
 use Try::Tiny;
 
-our $VERSION = 'v0.3.1';
+our $VERSION = 'v0.3.2';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -152,7 +152,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.3.1
+version v0.3.2
 
 =head1 SYNOPSIS
 
@@ -162,8 +162,8 @@ version v0.3.1
   builder {
 
     enable "Statsd",
-      client        => Net::Statsd::Tiny->new( ... ),
-      sampling_rate => 1.0;
+      client      => Net::Statsd::Tiny->new( ... ),
+      sample_rate => 1.0;
 
     ...
 
@@ -225,6 +225,13 @@ L<Net::Statsd::Client>.
 
 Other statsd client modules may be used via a wrapper class.
 
+=head2 sample_rate
+
+The default sampling rate to used, which should be a value between 0 and 1.
+This will override the default rate of the L</client>, if there is one.
+
+The default is C<1>.
+
 =head1 METRICS
 
 The following metrics are logged:
